@@ -13,7 +13,7 @@ use Process              ();
 
 use vars qw{$VERSION @ISA @DELEGATE};
 BEGIN {
-	$VERSION  = '1.12';
+	$VERSION  = '1.13';
 	@ISA      = qw{
 		Process::Delegatable
 		Process::Storable
@@ -44,12 +44,9 @@ my %MODULES = (
 		ExtUtils::ParseXS
 		version
 		Scalar::Util
-		IO::Compress::Base
 		Compress::Raw::Zlib
 		Compress::Raw::Bzip2
-		IO::Compress::Zip
-		IO::Compress::Bzip2
-		Compress::Zlib
+		IO::Compress::Base
 		Compress::Bzip2
 		IO::Zlib
 		File::Spec
@@ -63,6 +60,7 @@ my %MODULES = (
 		Package::Constants
 		IO::String
 		Archive::Tar
+		Compress::unLZMA
 		Parse::CPAN::Meta
 		YAML
 		Net::FTP
@@ -184,8 +182,6 @@ sub run {
 	# Squash all output that CPAN might spew during this process
 	my $stdout = IO::Capture::Stdout->new;
 	my $stderr = IO::Capture::Stderr->new;
-	$stdout->start;
-	$stderr->start;
 	
 	# Find the module
 	my $core = delete $self->{corelist};
@@ -196,11 +192,12 @@ sub run {
 			next;
 		}
 
-		# Get the CPAN object for the module
+		# Get the CPAN object for the module, covering any output.
+		$stdout->start;		$stderr->start;
 		my $module = CPAN::Shell->expand('Module', $name);
+		$stdout->stop;		$stderr->stop;
 		unless ( $module ) {
-			$self->{errstr} = "Failed to find '$name'";
-			return 0;
+			die "Failed to find '$name'";
 		}
 
 		# Ignore modules that don't need to be updated
@@ -229,10 +226,6 @@ sub run {
 	my %seen = ();
 	@{$self->{dists}} = grep { ! $seen{$_}++ } @{$self->{dists}};
 
-	# Free up stdout/stderr for normal output again
-	$stdout->stop;
-	$stderr->stop;
-
 	return 1;
 }
 
